@@ -272,18 +272,12 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 	if ctx.IsSet("stream-tls-key") {
 		config.StreamTLSKey = ctx.String("stream-tls-key")
 	}
-	if ctx.IsSet("stream-idle-timeout") {
-		config.StreamIdleTimeout = ctx.String("stream-idle-timeout")
-	}
 	if ctx.IsSet("version-file") {
 		config.VersionFile = ctx.String("version-file")
 	}
 	if ctx.IsSet("version-file-persist") {
 		config.VersionFilePersist = ctx.String("version-file-persist")
 	}
-	if ctx.IsSet("clean-shutdown-file") {
-		config.CleanShutdownFile = ctx.String("clean-shutdown-file")
-	}
 	if ctx.IsSet("enable-metrics") {
 		config.EnableMetrics = ctx.Bool("enable-metrics")
 	}
@@ -296,6 +290,9 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 	if ctx.IsSet("big-files-temporary-dir") {
 		config.BigFilesTemporaryDir = ctx.String("big-files-temporary-dir")
 	}
+	if ctx.IsSet("separate-pull-cgroup") {
+		config.SeparatePullCgroup = ctx.String("separate-pull-cgroup")
+	}
 
 	return nil
 }
@@ -422,6 +419,11 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars:   []string{"CONTAINER_PAUSE_IMAGE_AUTH_FILE"},
 			TakesFile: true,
 		},
+		&cli.StringFlag{
+			Name:    "separate-pull-cgroup",
+			Usage:   fmt.Sprintf("[EXPERIMENTAL] Pull in new cgroup (default: %q)", defConf.SeparatePullCgroup),
+			EnvVars: []string{"PULL_IN_A_CGROUP"},
+		},
 		&cli.StringFlag{
 			Name:      "global-auth-file",
 			Usage:     fmt.Sprintf("Path to a file like /var/lib/kubelet/config.json holding credentials necessary for pulling images from secure registries (default: %q)", defConf.GlobalAuthFile),
@@ -731,7 +733,7 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 		},
 		&cli.BoolFlag{
 			Name:    "manage-ns-lifecycle",
-			Usage:   fmt.Sprintf("Determines whether we pin and remove IPC, network and UTS namespaces and manage their lifecycle (default: %v)", defConf.ManageNSLifecycle),
+			Usage:   fmt.Sprintf("Determines whether we pin and remove IPC, network and UTS namespaces and manage their lifecycle. This option is being deprecated, and will be unconditionally true in the future. (default: %v)", defConf.ManageNSLifecycle),
 			EnvVars: []string{"CONTAINER_MANAGE_NS_LIFECYCLE"},
 		},
 		&cli.BoolFlag{
@@ -778,11 +780,6 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars:   []string{"CONTAINER_TLS_KEY"},
 			TakesFile: true,
 		},
-		&cli.StringFlag{
-			Name:    "stream-idle-timeout",
-			Usage:   "Length of time until open streams terminate due to lack of activity",
-			EnvVars: []string{"STREAM_IDLE_TIMEOUT"},
-		},
 		&cli.StringFlag{
 			Name:        "registries-conf",
 			Usage:       "path to the registries.conf file",
@@ -805,13 +802,6 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars:   []string{"CONTAINER_VERSION_FILE_PERSIST"},
 			TakesFile: true,
 		},
-		&cli.StringFlag{
-			Name:      "clean-shutdown-file",
-			Usage:     "Location for CRI-O to lay down the clean shutdown file. It indicates whether we've had time to sync changes to disk before shutting down. If not found, crio wipe will clear the storage directory",
-			Value:     defConf.CleanShutdownFile,
-			EnvVars:   []string{"CONTAINER_CLEAN_SHUTDOWN_FILE"},
-			TakesFile: true,
-		},
 	}
 }
 
